merlin.core.generators module (removed)
======================================

.. warning:: *Deprecated since version 0.3:*
    This module has been removed.
    Use :mod:`merlin.core.state` for input-state helpers and :class:`~merlin.builder.circuit_builder.CircuitBuilder`
    to build circuits.
